@@ -6,7 +6,7 @@ class OverloadException(Exception):
 
 class OverloadNotFound(OverloadException):
     """
-    Exception to raise if a function is called with certian argument types but this function hasn't been overloaded with those types
+    Exception to raise if a function is called with certain argument types but this function hasn't been overloaded with those types
     """
     pass
 
@@ -36,3 +36,7 @@ class ValidationValueError(ValidationError, ValueError):
 
 class ValidationDuplicationError(ValidationError):
     pass
+
+
+class TimeoutError(AssertionError):
+    pass
