@@ -1,4 +1,5 @@
-from typing import Sequence, Callable, Union, Any
+from typing import Sequence, Union, Any
+from collections.abc import Callable
 from .Decorators import validate
 from .Colors import ColoredText
 from .Classes import DisablePytestDiscovery
@@ -22,7 +23,7 @@ class Test(DisablePytestDiscovery):
     def __init__(self, inputs: Union[Sequence, Any], outputs: Union[Sequence, Any] = None, exception=None):
         if outputs is None and exception is None:
             raise ValueError(
-                "Cannot create a test where which doesnt return anything and not raises any exception")
+                "Cannot create a test where which doesn't return anything and not raises any exception")
         if outputs and exception:
             raise ValueError("cant check both return value and exception")
 
@@ -66,13 +67,17 @@ class TestFactory(DisablePytestDiscovery):
                 res = self.func(* test.inputs)
                 if not isinstance(res, tuple):
                     res = (res,)
-                msg = f"{count}: {self.func.__qualname__}{test.inputs} => {res}, := {test.outputs}"
+                msg = f"{count}: {self.func.__qualname__}{test.inputs} => {res} := {test.outputs}"
                 if res == test.outputs:
                     passed_test = True
             except Exception as e:
-                msg = f"{count}: {self.func.__qualname__}{test.inputs} => {type(e).__qualname__}{e.args}, := {test.exceptions}"
                 if type(e).__qualname__ == test.exceptions:
                     passed_test = True
+                msg = f"{count}: {self.func.__qualname__}{test.inputs} => {type(e).__qualname__}"
+                if passed_test:
+                    msg += f" := {test.exceptions}"
+                else:
+                    msg += f"{e.args} := {test.exceptions}"
             finally:
                 if passed_test:
                     pass_count += 1
@@ -104,7 +109,7 @@ def create_test_file(path: str, output_folder: str = None, overwrite: bool = Fal
         return False
     lines = filter(is_ok, lines)
 
-    infile_parts = []
+    in_file_parts = []
     import_path = ".".join([part for part in Path(path).parts])[:-3]
     res = [
         "from danielutils import TestFactory, Test\n",
@@ -119,8 +124,8 @@ def create_test_file(path: str, output_folder: str = None, overwrite: bool = Fal
             indents = matches.regs[0][1]//4
         else:
             indents = 0
-        if indents == 0 and len(infile_parts) > 0:
-            infile_parts.pop()
+        if indents == 0 and len(in_file_parts) > 0:
+            in_file_parts.pop()
 
         if "@property" in line:
             is_property = True
@@ -129,9 +134,9 @@ def create_test_file(path: str, output_folder: str = None, overwrite: bool = Fal
         if line.strip().startswith("class"):
             class_name = re.findall(r"class (\b\w+\b)", line)
             if class_name:
-                infile_parts.append(class_name[0])
+                in_file_parts.append(class_name[0])
             continue
-        if indents != len(infile_parts):
+        if indents != len(in_file_parts):
             continue
 
         name = re.findall(r"def (.+?)\(", line.strip())
@@ -139,7 +144,7 @@ def create_test_file(path: str, output_folder: str = None, overwrite: bool = Fal
             continue
         name = name[0]
         res.append(f"def test_{name}():\n")
-        func_name = ".".join(v for v in infile_parts+[name])
+        func_name = ".".join(v for v in in_file_parts+[name])
 
         if is_property:
             params = "*args,**kwargs"
@@ -157,15 +162,13 @@ __all__ = [
     "Test",
     "TestFactory",
     "create_test_file"
-
-
 ]
 # def test_func(functor, inputs, outputs) -> None:
 #     if not callable(functor):
 #         raise TypeError("functor must return true for callable(functor)")
 
 #     if len(inputs) != len(outputs):
-#         raise ValueError("Amount of inputs and outputs is diffrent")
+#         raise ValueError("Amount of inputs and outputs is different")
 
 #     for input, output in zip(inputs, outputs):
 #         res = functor(*input[0], **input[1])
